summaryrefslogtreecommitdiff
path: root/conf/conf.h
diff options
context:
space:
mode:
Diffstat (limited to 'conf/conf.h')
-rw-r--r--conf/conf.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/conf/conf.h b/conf/conf.h
index 34c6818d..3e47c918 100644
--- a/conf/conf.h
+++ b/conf/conf.h
@@ -32,8 +32,9 @@ struct config {
struct iface_patt *router_id_from; /* Configured list of router ID iface patterns */
u32 router_id; /* Our Router ID */
- unsigned proto_default_debug; /* Default protocol debug mask */
- unsigned proto_default_mrtdump; /* Default protocol mrtdump mask */
+ u32 proto_default_debug; /* Default protocol debug mask */
+ u32 proto_default_mrtdump; /* Default protocol mrtdump mask */
+ u32 channel_default_debug; /* Default channel debug mask */
struct timeformat tf_route; /* Time format for 'show route' */
struct timeformat tf_proto; /* Time format for 'show protocol' */
struct timeformat tf_log; /* Time format for the logfile */